title: New website created!

# Hello!

This is a new [public-static](http://publicstatic.org) website.

Directory structure:

* pages — markdown-formatted web pages.
* static — static web site assets including stylesheets, javascript and images.
* templates — web page templates.

Public-static links:

* [Documentation](https://github.com/dreikanter/public-static/blob/master/README.md)
* [Homepage](http://github.com/dreikanter/public-static) at GitHub
